@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2017 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -43,15 +43,18 @@ import hashlib
 import binascii
 
 from appier_extras.parts.admin.models import base
+from appier_extras.parts.admin.models import role
 
 class Account(base.Base):
 
     ADMIN_TYPE = 1
     USER_TYPE = 2
+    ROLE_TYPE = 3
 
     ACCOUNT_S = {
         ADMIN_TYPE : "admin",
-        USER_TYPE : "user"
+        USER_TYPE : "user",
+        ROLE_TYPE : "role"
     }
 
     PREFIXES = [
@@ -70,12 +73,12 @@ class Account(base.Base):
     ROOT_EMAIL = "root@root.com"
 
     username = appier.field(
-        index = True,
+        index = "all",
         default = True
     )
 
     email = appier.field(
-        index = True,
+        index = "all",
         immutable = True,
         meta = "email"
     )
@@ -104,27 +107,27 @@ class Account(base.Base):
     )
 
     facebook_id = appier.field(
-        index = True,
+        index = "hashed",
         safe = True
     )
 
     twitter_username = appier.field(
-        index = True,
+        index = "hashed",
         safe = True
     )
 
     google_id = appier.field(
-        index = True,
+        index = "hashed",
         safe = True
     )
 
     live_id = appier.field(
-        index = True,
+        index = "hashed",
         safe = True
     )
 
     github_login = appier.field(
-        index = True,
+        index = "hashed",
         safe = True
     )
 
@@ -167,6 +170,13 @@ class Account(base.Base):
         meta = "datetime"
     )
 
+    roles = appier.field(
+        type = appier.references(
+            "Role",
+            name = "id"
+        )
+    )
+
     @classmethod
     def setup(cls):
         super(Account, cls).setup()
@@ -180,7 +190,7 @@ class Account(base.Base):
         # to be used (should be initialized) and then prints the initial
         # information about the account to be generated
         logger = appier.get_logger()
-        logger.info("Generating initial root account ...")
+        logger.info("Generating initial root account for %s model ..." % cls.__name__)
 
         # creates the structure to be used as the root account description
         # using the default value and then stores the account as it's going
@@ -296,7 +306,7 @@ class Account(base.Base):
         # "touches" the current account meaning that the last login value will be
         # updated to reflect the current time and then returns the current logged
         # in account to the caller method so that it may used (valid account)
-        account.touch_s()
+        account.touch_login_s()
         return account
 
     @classmethod
@@ -334,7 +344,16 @@ class Account(base.Base):
         # "touches" the current account meaning that the last login value will be
         # updated to reflect the current time and then returns the current logged
         # in account to the caller method so that it may used (valid account)
-        account.touch_s()
+        account.touch_login_s()
+        return account
+
+    @classmethod
+    def confirm(cls, confirmation_token, send_email = False):
+        # validates the current account and token for confirmation and
+        # if that's valid runs the confirm operation and returns the account
+        # associated to the caller method
+        account = cls.validate_confirmation(confirmation_token)
+        account.confirm_s(send_email = send_email)
         return account
 
     @classmethod
@@ -375,17 +394,12 @@ class Account(base.Base):
         return account.recover_s(send_email = send_email)
 
     @classmethod
-    def reset(cls, reset_token, password, password_confirm):
+    def reset(cls, reset_token, password, password_confirm, confirm = True):
         account = cls.validate_reset(reset_token)
+        if confirm: account.confirm_s()
         account.reset_s(password, password_confirm)
         return account
 
-    @classmethod
-    def confirm(cls, confirmation_token, send_email = False):
-        account = cls.validate_confirmation(confirmation_token)
-        account.confirm_s(send_email = send_email)
-        return account
-
     @classmethod
     def verify(cls, encoded, decoded):
         type, salt, digest, plain = cls.unpack(encoded)
@@ -480,6 +494,7 @@ class Account(base.Base):
         if "email" in session: delete("email")
         if "type" in session: delete("type")
         if "tokens" in session: delete("tokens")
+        if "views" in session: delete("views")
         if "meta" in session: delete("meta")
         if "params" in session: delete("params")
         for key in appier.legacy.keys(session):
@@ -500,17 +515,19 @@ class Account(base.Base):
             self.username = self.username.lower()
         if hasattr(self, "email") and self.email:
             self.email = self.email.lower()
-
-    def pre_create(self):
-        base.Base.pre_create(self)
-        self.key = self.secret()
-        self.confirmation_token = self.secret()
+        if hasattr(self, "roles") and len(self.roles_l) > 0:
+            self.type = Account.ROLE_TYPE
 
     def pre_save(self):
         base.Base.pre_save(self)
         if hasattr(self, "password") and self.password:
             self.password = self.encrypt(self.password)
 
+    def pre_create(self):
+        base.Base.pre_create(self)
+        self.key = self.secret()
+        self.confirmation_token = self.secret()
+
     def confirm_s(self, send_email = False):
         self.confirmation_token = None
         self.enabled = True
@@ -539,12 +556,44 @@ class Account(base.Base):
         self.reset_token = None
         self.save()
 
+    def add_role_s(self, name):
+        _role = role.Role.get(name = name)
+        if _role in self.roles_l: return
+        self.roles_l.append(_role)
+        self.save()
+
+    def remove_role_s(self, name):
+        _role = role.Role.get(name = name)
+        if not _role in self.roles_l: return
+        self.roles_l.remove(_role)
+        self.save()
+
     def tokens(self):
+        tokens = set()
+
         if self.type == Account.ADMIN_TYPE:
-            return ["*"]
+            tokens.update(["*"])
 
         if self.type == Account.USER_TYPE:
-            return ["base", "user"]
+            tokens.update(["base", "user"])
+
+        for role in self.roles_l:
+            tokens.update(role.tokens)
+
+        if "*" in tokens: tokens = ["*"]
+
+        tokens = list(tokens)
+        tokens.sort()
+
+        return tokens
+
+    def views(self):
+        views = []
+        for role in self.roles_l:
+            view_m = role.view_m(context = self)
+            if not view_m: continue
+            views.append(view_m)
+        return views
 
     def type_s(self, capitalize = False):
         type_s = Account.ACCOUNT_S.get(self.type, None)
@@ -561,8 +610,8 @@ class Account(base.Base):
         if not self.username: return self.email
         return "%s <%s>" % (self.username, self.email)
 
-    @appier.operation(name = "Touch")
-    def touch_s(self):
+    @appier.operation(name = "Touch Login")
+    def touch_login_s(self):
         # updates the last login of the account with the current timestamp
         # and saves the account so that this value is persisted
         self.last_login = time.time()
@@ -625,6 +674,10 @@ class Account(base.Base):
     def confirmed(self):
         return self.enabled
 
+    @property
+    def roles_l(self):
+        return self.roles
+
     def _set_session(self, unset = True, safes = [], method = "set"):
         cls = self.__class__
         if unset: cls._unset_session(safes = safes)
@@ -635,5 +688,6 @@ class Account(base.Base):
         set("email", self.email)
         set("type", self.type_s())
         set("tokens", self.tokens())
+        set("views", self.views())
         set("meta", self.meta)
         set("params", dict())
