@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2017 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -46,12 +46,12 @@ from appier_extras.parts.admin.models import base
 class Event(base.Base):
 
     name = appier.field(
-        index = True,
+        index = "all",
         default = True
     )
 
     handler = appier.field(
-        index = True
+        index = "all"
     )
 
     arguments = appier.field(
@@ -104,7 +104,7 @@ class Event(base.Base):
         name = "Import CSV",
         parameters = (
             ("CSV File", "file", "file"),
-            ("Empty source", "empty", bool, True)
+            ("Empty source", "empty", bool, False)
         )
     )
     def import_csv_s(cls, file, empty):
