@@ -74,10 +74,10 @@ class AdminPart(
     ):
         appier.Part.__init__(self, *args, **kwargs)
         self.account_c = account_c
-        self.layout = "fluid"
-        self.theme = "modern"
-        self.style = "romantic"
-        self.libs = "current"
+        self.layout = appier.conf("ADMIN_LAYOUT", "fluid")
+        self.theme = appier.conf("ADMIN_THEME", "modern")
+        self.style = appier.conf("ADMIN_STYLE", "romantic")
+        self.libs = appier.conf("ADMIN_LIBS", "current")
 
     def load(self):
         appier.Part.load(self)
@@ -251,16 +251,8 @@ class AdminPart(
         # retrieves the various fields that are going to be
         # used for the validation of the user under the current
         # authentication/authorization process
-        username = self.field(
-            "username",
-            mandatory = True,
-            not_empty = True
-        )
-        password = self.field(
-            "password",
-            mandatory = True,
-            not_empty = True
-        )
+        username = self.field("username", mandatory = True)
+        password = self.field("password", mandatory = True)
         next = self.field("next")
         socials = self.socials()
         try: account = self.account_c.login(username, password)
@@ -338,13 +330,11 @@ class AdminPart(
         )
         password = self.field(
             "password",
-            mandatory = True,
-            not_empty = True
+            mandatory = True
         )
         password_confirm = self.field(
             "password_confirm",
-            mandatory = True,
-            not_empty = True
+            mandatory = True
         )
         try: self.account_c.reset(reset_token, password, password_confirm)
         except appier.AppierException as error:
@@ -775,8 +765,7 @@ class AdminPart(
 
     @appier.ensure(token = "admin")
     def show_model(self, model):
-        token = "admin.models." + model
-        appier.ensure_login(self, token = token)
+        appier.ensure_login(self, token = "admin.models." + model)
         model = self.get_model(model)
         model.assert_is_concrete_g()
         object = appier.get_object(
@@ -797,6 +786,7 @@ class AdminPart(
 
     @appier.ensure(token = "admin")
     def show_model_json(self, model):
+        appier.ensure_login(self, token = "admin.models." + model)
         eager_l = self.field("eager_l", False, cast = bool)
         meta = self.field("meta", False, cast = bool)
         model = self.get_model(model)
@@ -811,6 +801,7 @@ class AdminPart(
 
     @appier.ensure(token = "admin")
     def show_model_csv(self, model):
+        appier.ensure_login(self, token = "admin.models." + model)
         eager_l = self.field("eager_l", False, cast = bool)
         meta = self.field("meta", False, cast = bool)
         model = self.get_model(model)
@@ -946,6 +937,7 @@ class AdminPart(
 
     @appier.ensure(token = "admin")
     def show_entity(self, model, _id):
+        appier.ensure_login(self, token = "admin.models." + model)
         model = self.get_model(model)
         entity = model.get_v(
             rules = False,
@@ -961,6 +953,7 @@ class AdminPart(
 
     @appier.ensure(token = "admin")
     def show_entity_json(self, model, _id):
+        appier.ensure_login(self, token = "admin.models." + model)
         eager_l = self.field("eager_l", True, cast = bool)
         rules = self.field("rules", False, cast = bool)
         meta = self.field("meta", False, cast = bool)
@@ -976,6 +969,7 @@ class AdminPart(
 
     @appier.ensure(token = "admin")
     def edit_entity(self, model, _id):
+        appier.ensure_login(self, token = "admin.models." + model)
         model = self.get_model(model)
         entity = model.get_v(
             rules = False,
@@ -992,6 +986,7 @@ class AdminPart(
 
     @appier.ensure(token = "admin")
     def update_entity(self, model, _id):
+        appier.ensure_login(self, token = "admin.models." + model)
         model = self.get_model(model)
         entity = model.get_v(
             rules = False,
@@ -1019,6 +1014,7 @@ class AdminPart(
 
     @appier.ensure(token = "admin")
     def delete_entity(self, model, _id):
+        appier.ensure_login(self, token = "admin.models." + model)
         model = self.get_model(model)
         entity = model.get_v(_id = self.get_adapter().object_id(_id))
         entity.delete()
