@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2017 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -39,8 +39,6 @@ __license__ = "Apache License, Version 2.0"
 
 import appier
 
-from appier_extras.parts.admin import models
-
 class Facebook(object):
 
     def has_facebook(self):
@@ -51,10 +49,11 @@ class Facebook(object):
         if not appier.conf("FB_SECRET"): return False
         return True
 
-    def ensure_facebook_account(self, create = True):
+    def ensure_facebook_account(self, create = True, owner = None):
+        owner = owner or appier.get_app()
         api = self.get_facebook_api()
         user = api.self_user()
-        account = models.Account.get(
+        account = owner.admin_account.get(
             email = user["email"],
             rules = False,
             raise_e = False
@@ -65,14 +64,14 @@ class Facebook(object):
                 message = "no account found for facebook account"
             )
 
-            account = models.Account(
+            account = owner.admin_account(
                 username = user["email"],
                 email = user["email"],
                 password = api.access_token,
                 password_confirm = api.access_token,
                 facebook_id = user["id"],
                 facebook_token = api.access_token,
-                type = models.Account.USER_TYPE
+                type = owner.admin_account.USER_TYPE
             )
             account.save()
             account = account.reload(rules = False)
@@ -86,7 +85,7 @@ class Facebook(object):
             account.facebook_token = api.access_token
             account.save()
 
-        account.touch_s()
+        account.touch_login_s()
         account._set_session()
 
         return account
